@@ -26,6 +26,7 @@ import argparse
 import logging
 import os
 import pathlib
+import shutil
 import sys
 from typing import List
 
@@ -33,6 +34,7 @@ from cli_rack import CLI, ansi
 from cli_rack.modular import CliAppManager, CliExtension
 from cli_rack.utils import run_executable
 
+from jointbox_cli import scaffold
 from jointbox_cli.yaml_tools import JointboxYamlTools
 from strome.core import Pipeline, run_pipeline
 
@@ -113,6 +115,70 @@ class CompileExtension(ConfigAwareCliExtension):
         self.run_esphome("compile", config_path)
 
 
+class CleanExtension(CliExtension):
+    COMMAND_NAME = "clean"
+    COMMAND_DESCRIPTION = "Cleans up all generated files and invalidates cache"
+
+    DEFAULT_LOCATIONS = [
+        "generated",
+        "build",
+    ]
+
+    def rm_if_exists(self, path: str):
+        if os.path.isdir(path):
+            shutil.rmtree(path)
+        elif os.path.exists(path):
+            os.remove(path)
+        CLI.print_info("\t* {}".format(path))
+
+    def clean_defaults(self):
+        for x in self.DEFAULT_LOCATIONS:
+            self.rm_if_exists(x)
+
+    def handle(self, args: argparse.Namespace):
+        CLI.print_info("Cleaning default directories:")
+        self.clean_defaults()
+
+
+class ScaffoldCliExtension(CliExtension):
+    COMMAND_NAME = "scaffold"
+    COMMAND_DESCRIPTION = "Generates template for the new component or skeleton for the new project"
+
+    GENERATORS = [
+        scaffold.SelfGenerator,
+    ]
+
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
+
+    @classmethod
+    def setup_parser(cls, parser: argparse.ArgumentParser):
+        generator_command = parser.add_subparsers(
+            title="Available generators",
+            metavar="generator",
+            dest="generator",
+            description='Use "<generator> -h" to get information ' "about particular generator",
+        )
+        for generator_cls in cls.GENERATORS:
+            generator_parser = generator_command.add_parser(
+                generator_cls.COMMAND_NAME, help=generator_cls.COMMAND_DESCRIPTION
+            )
+            generator_cls.setup_parser(generator_parser)
+            generator_parser.set_defaults(generator_cls=generator_cls)
+
+    def setup(self, *args, **kwargs):
+        super().setup(*args, **kwargs)
+
+    def handle(self, args):
+        generator: scaffold.BaseGenerator = args.generator_cls()
+        generator.setup()
+        try:
+            generator.check_preconditions(args.path)
+        except scaffold.PreconditionsFailedError as e:
+            CLI.fail(e)
+        generator.handle(args)
+
+
 def main(argv: List[str]):
     CLI.setup()
     CLI.debug_mode()
@@ -122,6 +188,8 @@ def main(argv: List[str]):
     app_manager.register_extension(ConfigExtension)
     app_manager.register_extension(RunExtension)
     app_manager.register_extension(CompileExtension)
+    app_manager.register_extension(CleanExtension)
+    app_manager.register_extension(ScaffoldCliExtension)
     app_manager.setup()
     JointboxYamlTools.initialize()
     try:
