@@ -31,7 +31,6 @@ from cli_rack.loader import LoadedDataMeta, DefaultLoaderRegistry, LoaderRegistr
 from cli_rack.utils import none_throws, safe_cast
 
 from cli_rack_validation import crv
-from strome.utils import yaml_file_to_dict
 from .const import CONTEXT_PKG, CONTEXT_VARS, CONTEXT_MACROS, CONTEXT_META, CONTEXT_PACKAGES
 from .validation import _validate_package_config, _is_short_package_config_syntax
 from .common import PackageDefinition, PackageConfig, PackageSource, PackageMeta, MacroDef, BaseMeta, RootMeta
@@ -39,6 +38,7 @@ from ..expressions import register_global
 from ..expressions.core import ExpressionEvaluator
 from ... import const
 from ...const import CONTEXT_SECRETS
+from ...core import load_yaml_config_file
 from ...validate import (
     valid_params_def,
     ParameterValidators,
@@ -247,7 +247,7 @@ class PackageProcessor(object):
                 ["source"],
             )
         # Read yaml file
-        package_dict = yaml_file_to_dict(package_file)
+        package_dict = load_yaml_config_file(package_file)
         package_def.file_system_location = package_file
         # Recursively load subpackages
         package_def.content = package_dict
